@@ -478,7 +478,7 @@ burn_cd (CDDrive *rec, const char *source_iso, const char *label, gboolean eject
 			g_print ("Writing ISO onto ISO, you freak!\n");
 			return RESULT_FINISHED;
 		}
-		filesel = gtk_file_selection_new (_("Choose a filename for the cdrom image"));
+		filesel = gtk_file_selection_new (_("Choose a filename for the CD-ROM image"));
 		gtk_file_selection_set_filename (GTK_FILE_SELECTION (filesel),
 						 "~/image.iso");
 
@@ -636,7 +636,7 @@ refresh_dialog (GladeXML *xml)
 
 	/* Disable blank for burn-to-iso */
 	blank_check = glade_xml_get_widget (xml, "blank_check");
-	gtk_widget_set_sensitive (blank_check, rec->type != CDDRIVE_TYPE_FILE);
+	gtk_widget_set_sensitive (blank_check, rec->type & CDDRIVE_TYPE_CDRW_RECORDER);
 
 	/* Disable music for burn-to-iso */
 	music_check = glade_xml_get_widget (xml, "music_check");
@@ -720,6 +720,10 @@ init_dialog (GladeXML *xml, GtkWidget *dialog, GnomeVFSFileSize size, char *disc
 	} else {
 		time (&now);
 		tm = localtime (&now);
+		/*
+		translators: see stftime man page for meaning of %b, %d and %Y
+		the maximum length for this field is 32 characters
+		*/
 		strftime (buf, sizeof (buf), _("Personal Data, %b %d, %Y"), tm);	
 		gtk_entry_set_text (GTK_ENTRY (entry), buf);
 	}
